@@ -1,6 +1,6 @@
 /*
- * Copyright 2023, Steinberg Media Technologies GmbH, All Rights Reserved
- * Copyright 2023 Linux Studio Plugins Project <lsp.plugin@gmail.com>
+ * Copyright 2025, Steinberg Media Technologies GmbH, All Rights Reserved
+ * Copyright 2025 Linux Studio Plugins Project <lsp.plugin@gmail.com>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,5 +28,7 @@
 #include <steinberg/vst3/gui/IEventHandler.h>
 #include <steinberg/vst3/gui/ITimerHandler.h>
 #include <steinberg/vst3/gui/IRunLoop.h>
+#include <steinberg/vst3/gui/IWaylandHost.h>
+#include <steinberg/vst3/gui/IWaylandFrame.h>
 
 #endif /* _3RD_PARTY_STEINBERG_VST3_VST_H_ */
