@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2020 Linux Studio Plugins Project <https://lsp-plug.in/>
- *           (C) 2020 Vladimir Sadovnikov <sadko4u@gmail.com>
+ * Copyright (C) 2024 Linux Studio Plugins Project <https://lsp-plug.in/>
+ *           (C) 2024 Vladimir Sadovnikov <sadko4u@gmail.com>
  *
  * This file is part of lsp-common-lib
  * Created on: 21 нояб. 2020 г.
@@ -24,7 +24,17 @@
 
 #include <lsp-plug.in/common/version.h>
 #include <lsp-plug.in/common/types.h>
-#include <stdlib.h>
+
+#ifndef PLATFORM_HAIKU
+	#include <stdlib.h>
+#else
+	#ifndef _GNU_SOURCE
+		#define _GNU_SOURCE
+	#endif /* _GNU_SOURCE */
+	
+	#include <stdlib.h>
+	#include <gnu/stdlib.h>
+#endif /* PLATFORM_HAIKU */
 
 namespace lsp
 {
