@@ -104,11 +104,11 @@ namespace lsp
                       [k] "=&r" (k), [n] "+r" (n)
                     : [dst] "r" (tmp)
                     : "cc", "memory",
-                      "q0", "q1", "q2", "q3",
-                      "q4", "q5", "q6", "q7",
-                      "q16", "q17", "q18", "q19",
-                      "q20", "q21", "q22", "q23",
-                      "q24", "q25"
+                      "v0", "v1", "v2", "v3",
+                      "v4", "v5", "v6", "v7",
+                      "v16", "v17", "v18", "v19",
+                      "v20", "v21", "v22", "v23",
+                      "v24", "v25"
                 );
 
                 // All other loops while n > 4
@@ -225,11 +225,11 @@ namespace lsp
                       [n] "+r" (n)
                     : [dst] "r" (tmp), [items] "r" (items)
                     : "cc", "memory",
-                      "q0", "q1", "q2", "q3",
-                      "q4", "q5", "q6", "q7",
-                      "q16", "q17", "q18", "q19",
-                      "q20", "q21", "q22", "q23",
-                      "q24", "q25"
+                      "v0", "v1", "v2", "v3",
+                      "v4", "v5", "v6", "v7",
+                      "v16", "v17", "v18", "v19",
+                      "v20", "v21", "v22", "v23",
+                      "v24", "v25"
                 );
             }
             else
@@ -242,7 +242,7 @@ namespace lsp
                     :
                     : [src] "r" (src), [dst] "r" (tmp)
                     : "memory",
-                      "q0", "q1"
+                      "v0", "v1"
                 );
             }
 
@@ -345,9 +345,9 @@ namespace lsp
                 : [tmp] "r" (tmp), [items] "r" (items),
                   [MASK] "r" (&fastconv_swp_mask[0])
                 : "cc", "memory",
-                  "q0", "q1", "q2", "q3", "q4", "q5", "q6", "q7",
-                  "q16", "q17", "q18", "q19", "q20", "q21", "q22", "q23",
-                  "q24", "q25"
+                  "v0", "v1", "v2", "v3", "v4", "v5", "v6", "v7",
+                  "v16", "v17", "v18", "v19", "v20", "v21", "v22", "v23",
+                  "v24", "v25"
             );
 
             //---------------------------------------------------------------------
@@ -421,8 +421,8 @@ namespace lsp
                       [XFFT_A] "+r" (fw)
                     : [tmp] "r" (tmp), [items] "r" (items)
                     : "cc", "memory",
-                      "q0", "q1", "q2", "q3", "q4", "q5", "q6", "q7",
-                      "q16", "q17", "q18", "q19", "q20", "q21", "q22", "q23"
+                      "v0", "v1", "v2", "v3", "v4", "v5", "v6", "v7",
+                      "v16", "v17", "v18", "v19", "v20", "v21", "v22", "v23"
                 );
 
                 n <<= 1;
@@ -499,9 +499,9 @@ namespace lsp
                     : [tmp] "r" (tmp), [items] "r" (items), [n] "r" (n),
                       [XFFT_A] "r" (fw), [XFFT_DW] "r" (fdw)
                     : "cc", "memory",
-                      "q0", "q1", "q2", "q3", "q4", "q5", "q6", "q7",
-                      "q16", "q17", "q18", "q19", "q20", "q21", "q22", "q23",
-                      "q24", "q25"
+                      "v0", "v1", "v2", "v3", "v4", "v5", "v6", "v7",
+                      "v16", "v17", "v18", "v19", "v20", "v21", "v22", "v23",
+                      "v24", "v25"
                 );
 
                 n <<= 1;
@@ -572,9 +572,9 @@ namespace lsp
                 : [n] "r" (n), [fftk] "r" (&fftk),
                   [XFFT_A] "r" (fw), [XFFT_DW] "r" (fdw)
                 : "cc", "memory",
-                  "q0", "q1", "q2", "q3", "q4", "q5", "q6", "q7",
-                  "q16", "q17", "q18", "q19", "q20", "q21", "q22", "q23",
-                  "q24", "q25"
+                  "v0", "v1", "v2", "v3", "v4", "v5", "v6", "v7",
+                  "v16", "v17", "v18", "v19", "v20", "v21", "v22", "v23",
+                  "v24", "v25"
             );
         }
     }
