@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2020 Linux Studio Plugins Project <https://lsp-plug.in/>
- *           (C) 2020 Vladimir Sadovnikov <sadko4u@gmail.com>
+ * Copyright (C) 2023 Linux Studio Plugins Project <https://lsp-plug.in/>
+ *           (C) 2023 Vladimir Sadovnikov <sadko4u@gmail.com>
  *
  * This file is part of lsp-dsp-lib
  * Created on: 31 мар. 2020 г.
@@ -30,16 +30,37 @@ namespace lsp
 {
     namespace asimd
     {
+        #define POW_LOAD_VALUES \
+            __ASM_EMIT("ldp             q16, q17, [%[P2C], #0x000]")    /* v16  = LC0, v17  = LC1 */ \
+            __ASM_EMIT("ldp             q18, q19, [%[P2C], #0x020]")    /* v18  = LC2, v19  = LC3 */ \
+            __ASM_EMIT("ldp             q20, q21, [%[P2C], #0x040]")    /* v20  = LC4, v21  = EC5 */ \
+            __ASM_EMIT("ldp             q24, q25, [%[P2C], #0x060]")    /* v24  = EC4, v25  = EC3 */ \
+            __ASM_EMIT("ldp             q26, q27, [%[P2C], #0x080]")    /* v26  = EC2, v27  = EC1 */ \
+            __ASM_EMIT("ldp             q28, q29, [%[P2C], #0x0a0]")    /* v28  = EC0, v29  = EC6 */ \
+            __ASM_EMIT("ldp             q30, q31, [%[P2C], #0x0c0]")    /* v30  = MM , v31  = ME */ \
+            __ASM_EMIT("ldp             q12, q13, [%[P2C], #0x0e0]")    /* v12  = C7 , v13  = L2 */ \
+            __ASM_EMIT("ldr             q14, [%[P2C], #0x100]")         /* v14  = LE */
+
+        #define POW_LOG_X4 \
+            LOGN_CORE_X4("v30", "v31", "v16", "v17", "v18", "v19", "v20", "v12")
+
+        #define POW_LOG_X8 \
+            LOGN_CORE_X8("v30", "v31", "v16", "v17", "v18", "v19", "v20", "v12")
+
+        #define POW_POW2_X8 \
+            POW2_CORE_X8("v31", "v13", "v21", "v24", "v25", "v26", "v27", "v28", "v29", "v12")
+
+        #define POW_POW2_X4 \
+            POW2_CORE_X4("v31", "v13", "v21", "v24", "v25", "v26", "v27", "v28", "v29", "v12")
+
         IF_ARCH_AARCH64(
             static const uint32_t POW_CONST[] __lsp_aligned16 =
             {
-                LSP_DSP_VEC4(0x3d888889), // LC0 = 1/15 = 0.0666666701436043
-                LSP_DSP_VEC4(0x3d9d89d9), // LC1 = 1/13 = 0.0769230797886848
-                LSP_DSP_VEC4(0x3dba2e8c), // LC2 = 1/11 = 0.0909090936183929
-                LSP_DSP_VEC4(0x3de38e39), // LC3 = 1/9 = 0.1111111119389534
-                LSP_DSP_VEC4(0x3e124925), // LC4 = 1/7 = 0.1428571492433548
-                LSP_DSP_VEC4(0x3e4ccccd), // LC5 = 1/5 = 0.2000000029802322
-                LSP_DSP_VEC4(0x3eaaaaab), // LC6 = 1/3 = 0.3333333432674408
+                LSP_DSP_VEC4(0x3dba2e8c), // LC0 = 1/11 = 0.0909090936183929
+                LSP_DSP_VEC4(0x3de38e39), // LC1 = 1/9 = 0.1111111119389534
+                LSP_DSP_VEC4(0x3e124925), // LC2 = 1/7 = 0.1428571492433548
+                LSP_DSP_VEC4(0x3e4ccccd), // LC3 = 1/5 = 0.2000000029802322
+                LSP_DSP_VEC4(0x3eaaaaab), // LC4 = 1/3 = 0.3333333432674408
                 LSP_DSP_VEC4(0x40e00000), // EC5 = 7!/6! = 7.0000000000000000
 
                 LSP_DSP_VEC4(0x42280000), // EC4 = 7!/5! = 42.0000000000000000
@@ -64,18 +85,9 @@ namespace lsp
     //            v[i] = expf(v[i] * C);
             ARCH_AARCH64_ASM(
                 __ASM_EMIT("dup             v0.4s, %[C].s[0]")              // v15  = C
-                __ASM_EMIT("ldr             q14, [%[P2C], #0x120]")         // v14  = LE
-                __ASM_EMIT("ldp             q16, q17, [%[P2C], #0x000]")    // v16  = LC0, v17  = LC1
-                __ASM_EMIT("ldp             q18, q19, [%[P2C], #0x020]")    // v18  = LC2, v19  = LC3
-                __ASM_EMIT("ldp             q20, q21, [%[P2C], #0x040]")    // v20  = LC4, v21  = LC5
-                __ASM_EMIT("ldp             q22, q23, [%[P2C], #0x060]")    // v22  = LC6, v23  = EC5
-                __ASM_EMIT("ldp             q24, q25, [%[P2C], #0x080]")    // v24  = EC4, v25  = EC3
-                __ASM_EMIT("ldp             q26, q27, [%[P2C], #0x0a0]")    // v26  = EC2, v27  = EC1
-                __ASM_EMIT("ldp             q28, q29, [%[P2C], #0x0c0]")    // v28  = EC0, v29  = EC6
-                __ASM_EMIT("ldp             q30, q31, [%[P2C], #0x0e0]")    // v30  = MM , v31  = ME
-                __ASM_EMIT("ldp             q12, q13, [%[P2C], #0x100]")    // v12  = C7 , v13  = L2
+                POW_LOAD_VALUES
                 // log(c)
-                LOGN_CORE_X4("v30", "v31", "v16", "v17", "v18", "v19", "v20", "v21", "v22", "v12")
+                POW_LOG_X4
                 __ASM_EMIT("fmul            v0.4s, v0.4s, v14.4s")          // v0   = 2*y*L*log2(E)
                 __ASM_EMIT("fadd            v15.4s, v0.4s, v2.4s")          // v15  = 2*y*L*log2(E) + R = log(c)*log2(E)
                 __ASM_EMIT("subs            %[count], %[count], #8")
@@ -85,7 +97,7 @@ namespace lsp
                 __ASM_EMIT("ldp             q0, q1, [%[src]]")
                 __ASM_EMIT("fmul            v0.4s, v0.4s, v15.4s")
                 __ASM_EMIT("fmul            v1.4s, v1.4s, v15.4s")
-                POW2_CORE_X8("v31", "v13", "v23", "v24", "v25", "v26", "v27", "v28", "v29", "v12")
+                POW_POW2_X8
                 __ASM_EMIT("subs            %[count], %[count], #8")
                 __ASM_EMIT("stp             q0, q1, [%[dst]]")
                 __ASM_EMIT("add             %[src], %[src], #0x20")
@@ -97,7 +109,7 @@ namespace lsp
                 __ASM_EMIT("b.lt            4f")
                 __ASM_EMIT("ldr             q0, [%[src]]")
                 __ASM_EMIT("fmul            v0.4s, v0.4s, v15.4s")
-                POW2_CORE_X4("v31", "v13", "v23", "v24", "v25", "v26", "v27", "v28", "v29", "v12")
+                POW_POW2_X4
                 __ASM_EMIT("sub             %[count], %[count], #4")
                 __ASM_EMIT("str             q0, [%[dst]]")
                 __ASM_EMIT("add             %[src], %[src], #0x10")
@@ -116,7 +128,7 @@ namespace lsp
                 __ASM_EMIT("ld1             {v0.d}[1], [%[src]]")
                 __ASM_EMIT("8:")
                 __ASM_EMIT("fmul            v0.4s, v0.4s, v15.4s")
-                POW2_CORE_X4("v31", "v13", "v23", "v24", "v25", "v26", "v27", "v28", "v29", "v12")
+                POW_POW2_X4
                 __ASM_EMIT("tst             %[count], #1")
                 __ASM_EMIT("b.eq            10f")
                 __ASM_EMIT("st1             {v0.s}[0], [%[dst]]")
@@ -150,18 +162,9 @@ namespace lsp
     //            v[i] = expf(v[i] * C);
             ARCH_AARCH64_ASM(
                 __ASM_EMIT("dup             v0.4s, %[C].s[0]")              // v15  = C
-                __ASM_EMIT("ldr             q14, [%[P2C], #0x120]")         // v14  = LE
-                __ASM_EMIT("ldp             q16, q17, [%[P2C], #0x000]")    // v16  = LC0, v17  = LC1
-                __ASM_EMIT("ldp             q18, q19, [%[P2C], #0x020]")    // v18  = LC2, v19  = LC3
-                __ASM_EMIT("ldp             q20, q21, [%[P2C], #0x040]")    // v20  = LC4, v21  = LC5
-                __ASM_EMIT("ldp             q22, q23, [%[P2C], #0x060]")    // v22  = LC6, v23  = EC5
-                __ASM_EMIT("ldp             q24, q25, [%[P2C], #0x080]")    // v24  = EC4, v25  = EC3
-                __ASM_EMIT("ldp             q26, q27, [%[P2C], #0x0a0]")    // v26  = EC2, v27  = EC1
-                __ASM_EMIT("ldp             q28, q29, [%[P2C], #0x0c0]")    // v28  = EC0, v29  = EC6
-                __ASM_EMIT("ldp             q30, q31, [%[P2C], #0x0e0]")    // v30  = MM , v31  = ME
-                __ASM_EMIT("ldp             q12, q13, [%[P2C], #0x100]")    // v12  = C7 , v13  = L2
+                POW_LOAD_VALUES
                 // log(c)
-                LOGN_CORE_X4("v30", "v31", "v16", "v17", "v18", "v19", "v20", "v21", "v22", "v12")
+                POW_LOG_X4
                 __ASM_EMIT("fmul            v0.4s, v0.4s, v14.4s")          // v0   = 2*y*L*log2(E)
                 __ASM_EMIT("fadd            v15.4s, v0.4s, v2.4s")          // v15  = 2*y*L*log2(E) + R = log(c)*log2(E)
                 __ASM_EMIT("subs            %[count], %[count], #8")
@@ -171,7 +174,7 @@ namespace lsp
                 __ASM_EMIT("ldp             q0, q1, [%[dst]]")
                 __ASM_EMIT("fmul            v0.4s, v0.4s, v15.4s")
                 __ASM_EMIT("fmul            v1.4s, v1.4s, v15.4s")
-                POW2_CORE_X8("v31", "v13", "v23", "v24", "v25", "v26", "v27", "v28", "v29", "v12")
+                POW_POW2_X8
                 __ASM_EMIT("subs            %[count], %[count], #8")
                 __ASM_EMIT("stp             q0, q1, [%[dst]]")
                 __ASM_EMIT("add             %[dst], %[dst], #0x20")
@@ -182,7 +185,7 @@ namespace lsp
                 __ASM_EMIT("b.lt            4f")
                 __ASM_EMIT("ldr             q0, [%[dst]]")
                 __ASM_EMIT("fmul            v0.4s, v0.4s, v15.4s")
-                POW2_CORE_X4("v31", "v13", "v23", "v24", "v25", "v26", "v27", "v28", "v29", "v12")
+                POW_POW2_X4
                 __ASM_EMIT("sub             %[count], %[count], #4")
                 __ASM_EMIT("str             q0, [%[dst]]")
                 __ASM_EMIT("add             %[dst], %[dst], #0x10")
@@ -200,7 +203,7 @@ namespace lsp
                 __ASM_EMIT("ld1             {v0.d}[1], [%[dst]]")
                 __ASM_EMIT("8:")
                 __ASM_EMIT("fmul            v0.4s, v0.4s, v15.4s")
-                POW2_CORE_X4("v31", "v13", "v23", "v24", "v25", "v26", "v27", "v28", "v29", "v12")
+                POW_POW2_X4
                 __ASM_EMIT("tst             %[count], #1")
                 __ASM_EMIT("b.eq            10f")
                 __ASM_EMIT("sub             %[dst], %[dst], #0x04")
@@ -234,27 +237,18 @@ namespace lsp
     //            dst[i] = expf(v * logf(c[i]));
             ARCH_AARCH64_ASM(
                 __ASM_EMIT("dup             v15.4s, %[V].s[0]")             // v15  = V
-                __ASM_EMIT("ldr             q14, [%[P2C], #0x120]")         // v14  = LE
-                __ASM_EMIT("ldp             q16, q17, [%[P2C], #0x000]")    // v16  = LC0, v17  = LC1
-                __ASM_EMIT("ldp             q18, q19, [%[P2C], #0x020]")    // v18  = LC2, v19  = LC3
-                __ASM_EMIT("ldp             q20, q21, [%[P2C], #0x040]")    // v20  = LC4, v21  = LC5
-                __ASM_EMIT("ldp             q22, q23, [%[P2C], #0x060]")    // v22  = LC6, v23  = EC5
-                __ASM_EMIT("ldp             q24, q25, [%[P2C], #0x080]")    // v24  = EC4, v25  = EC3
-                __ASM_EMIT("ldp             q26, q27, [%[P2C], #0x0a0]")    // v26  = EC2, v27  = EC1
-                __ASM_EMIT("ldp             q28, q29, [%[P2C], #0x0c0]")    // v28  = EC0, v29  = EC6
-                __ASM_EMIT("ldp             q30, q31, [%[P2C], #0x0e0]")    // v30  = MM , v31  = ME
-                __ASM_EMIT("ldp             q12, q13, [%[P2C], #0x100]")    // v12  = C7 , v13  = L2
+                POW_LOAD_VALUES
                 __ASM_EMIT("subs            %[count], %[count], #8")
                 __ASM_EMIT("b.lo            2f")
                 // x8 blocks
                 __ASM_EMIT("1:")
                 __ASM_EMIT("ldp             q0, q1, [%[src]]")
-                LOGN_CORE_X8("v30", "v31", "v16", "v17", "v18", "v19", "v20", "v21", "v22", "v12")
+                POW_LOG_X8
                 __ASM_EMIT("fmla            v2.4s, v0.4s, v14.4s")          // v2 = 2*y*L*log2(E) + R
                 __ASM_EMIT("fmla            v3.4s, v1.4s, v14.4s")
                 __ASM_EMIT("fmul            v0.4s, v2.4s, v15.4s")          // q0 = (2*y*L*log2(E) + R)*v = log(c[i])*v
                 __ASM_EMIT("fmul            v1.4s, v3.4s, v15.4s")
-                POW2_CORE_X8("v31", "v13", "v23", "v24", "v25", "v26", "v27", "v28", "v29", "v12")
+                POW_POW2_X8
                 __ASM_EMIT("subs            %[count], %[count], #8")
                 __ASM_EMIT("stp             q0, q1, [%[dst]]")
                 __ASM_EMIT("add             %[src], %[src], #0x20")
@@ -265,10 +259,10 @@ namespace lsp
                 __ASM_EMIT("adds            %[count], %[count], #4")
                 __ASM_EMIT("b.lt            4f")
                 __ASM_EMIT("ldr             q0, [%[src]]")
-                LOGN_CORE_X4("v30", "v31", "v16", "v17", "v18", "v19", "v20", "v21", "v22", "v12")
+                POW_LOG_X4
                 __ASM_EMIT("fmla            v2.4s, v0.4s, v14.4s")          // v2 = 2*y*L*log2(E) + R
                 __ASM_EMIT("fmul            v0.4s, v2.4s, v15.4s")          // q0 = (2*y*L*log2(E) + R)*v = log(c[i])*v
-                POW2_CORE_X4("v31", "v13", "v23", "v24", "v25", "v26", "v27", "v28", "v29", "v12")
+                POW_POW2_X4
                 __ASM_EMIT("subs            %[count], %[count], #4")
                 __ASM_EMIT("str             q0, [%[dst]]")
                 __ASM_EMIT("add             %[src], %[src], #0x10")
@@ -286,10 +280,10 @@ namespace lsp
                 __ASM_EMIT("b.eq            8f")
                 __ASM_EMIT("ld1             {v0.d}[1], [%[src]]")
                 __ASM_EMIT("8:")
-                LOGN_CORE_X4("v30", "v31", "v16", "v17", "v18", "v19", "v20", "v21", "v22", "v12")
+                POW_LOG_X4
                 __ASM_EMIT("fmla            v2.4s, v0.4s, v14.4s")          // v2 = 2*y*L*log2(E) + R
                 __ASM_EMIT("fmul            v0.4s, v2.4s, v15.4s")          // q0 = (2*y*L*log2(E) + R)*v = log(c[i])*v
-                POW2_CORE_X4("v31", "v13", "v23", "v24", "v25", "v26", "v27", "v28", "v29", "v12")
+                POW_POW2_X4
                 __ASM_EMIT("tst             %[count], #1")
                 __ASM_EMIT("b.eq            10f")
                 __ASM_EMIT("st1             {v0.s}[0], [%[dst]]")
@@ -322,27 +316,18 @@ namespace lsp
     //            c[i] = expf(v * logf(c[i]));
             ARCH_AARCH64_ASM(
                 __ASM_EMIT("dup             v15.4s, %[V].s[0]")             // v15  = V
-                __ASM_EMIT("ldr             q14, [%[P2C], #0x120]")         // v14  = LE
-                __ASM_EMIT("ldp             q16, q17, [%[P2C], #0x000]")    // v16  = LC0, v17  = LC1
-                __ASM_EMIT("ldp             q18, q19, [%[P2C], #0x020]")    // v18  = LC2, v19  = LC3
-                __ASM_EMIT("ldp             q20, q21, [%[P2C], #0x040]")    // v20  = LC4, v21  = LC5
-                __ASM_EMIT("ldp             q22, q23, [%[P2C], #0x060]")    // v22  = LC6, v23  = EC5
-                __ASM_EMIT("ldp             q24, q25, [%[P2C], #0x080]")    // v24  = EC4, v25  = EC3
-                __ASM_EMIT("ldp             q26, q27, [%[P2C], #0x0a0]")    // v26  = EC2, v27  = EC1
-                __ASM_EMIT("ldp             q28, q29, [%[P2C], #0x0c0]")    // v28  = EC0, v29  = EC6
-                __ASM_EMIT("ldp             q30, q31, [%[P2C], #0x0e0]")    // v30  = MM , v31  = ME
-                __ASM_EMIT("ldp             q12, q13, [%[P2C], #0x100]")    // v12  = C7 , v13  = L2
+                POW_LOAD_VALUES
                 __ASM_EMIT("subs            %[count], %[count], #8")
                 __ASM_EMIT("b.lo            2f")
                 // x8 blocks
                 __ASM_EMIT("1:")
                 __ASM_EMIT("ldp             q0, q1, [%[dst]]")
-                LOGN_CORE_X8("v30", "v31", "v16", "v17", "v18", "v19", "v20", "v21", "v22", "v12")
+                POW_LOG_X8
                 __ASM_EMIT("fmla            v2.4s, v0.4s, v14.4s")          // v2 = 2*y*L*log2(E) + R
                 __ASM_EMIT("fmla            v3.4s, v1.4s, v14.4s")
                 __ASM_EMIT("fmul            v0.4s, v2.4s, v15.4s")          // q0 = (2*y*L*log2(E) + R)*v = log(c[i])*v
                 __ASM_EMIT("fmul            v1.4s, v3.4s, v15.4s")
-                POW2_CORE_X8("v31", "v13", "v23", "v24", "v25", "v26", "v27", "v28", "v29", "v12")
+                POW_POW2_X8
                 __ASM_EMIT("subs            %[count], %[count], #8")
                 __ASM_EMIT("stp             q0, q1, [%[dst]]")
                 __ASM_EMIT("add             %[dst], %[dst], #0x20")
@@ -352,10 +337,10 @@ namespace lsp
                 __ASM_EMIT("adds            %[count], %[count], #4")
                 __ASM_EMIT("b.lt            4f")
                 __ASM_EMIT("ldr             q0, [%[dst]]")
-                LOGN_CORE_X4("v30", "v31", "v16", "v17", "v18", "v19", "v20", "v21", "v22", "v12")
+                POW_LOG_X4
                 __ASM_EMIT("fmla            v2.4s, v0.4s, v14.4s")          // v2 = 2*y*L*log2(E) + R
                 __ASM_EMIT("fmul            v0.4s, v2.4s, v15.4s")          // q0 = (2*y*L*log2(E) + R)*v = log(c[i])*v
-                POW2_CORE_X4("v31", "v13", "v23", "v24", "v25", "v26", "v27", "v28", "v29", "v12")
+                POW_POW2_X4
                 __ASM_EMIT("subs            %[count], %[count], #4")
                 __ASM_EMIT("str             q0, [%[dst]]")
                 __ASM_EMIT("add             %[dst], %[dst], #0x10")
@@ -372,10 +357,10 @@ namespace lsp
                 __ASM_EMIT("b.eq            8f")
                 __ASM_EMIT("ld1             {v0.d}[1], [%[dst]]")
                 __ASM_EMIT("8:")
-                LOGN_CORE_X4("v30", "v31", "v16", "v17", "v18", "v19", "v20", "v21", "v22", "v12")
+                POW_LOG_X4
                 __ASM_EMIT("fmla            v2.4s, v0.4s, v14.4s")          // v2 = 2*y*L*log2(E) + R
                 __ASM_EMIT("fmul            v0.4s, v2.4s, v15.4s")          // q0 = (2*y*L*log2(E) + R)*v = log(c[i])*v
-                POW2_CORE_X4("v31", "v13", "v23", "v24", "v25", "v26", "v27", "v28", "v29", "v12")
+                POW_POW2_X4
                 __ASM_EMIT("tst             %[count], #1")
                 __ASM_EMIT("b.eq            10f")
                 __ASM_EMIT("sub             %[dst], %[dst], #0x04")
@@ -408,28 +393,19 @@ namespace lsp
     //        for (size_t i=0; i<count; ++i)
     //            dst[i] = expf(x[i] * logf(v[i]));
             ARCH_AARCH64_ASM(
-                __ASM_EMIT("ldp             q16, q17, [%[P2C], #0x000]")    // v16  = LC0, v17  = LC1
-                __ASM_EMIT("ldp             q18, q19, [%[P2C], #0x020]")    // v18  = LC2, v19  = LC3
-                __ASM_EMIT("ldp             q20, q21, [%[P2C], #0x040]")    // v20  = LC4, v21  = LC5
-                __ASM_EMIT("ldp             q22, q23, [%[P2C], #0x060]")    // v22  = LC6, v23  = EC5
-                __ASM_EMIT("ldp             q24, q25, [%[P2C], #0x080]")    // v24  = EC4, v25  = EC3
-                __ASM_EMIT("ldp             q26, q27, [%[P2C], #0x0a0]")    // v26  = EC2, v27  = EC1
-                __ASM_EMIT("ldp             q28, q29, [%[P2C], #0x0c0]")    // v28  = EC0, v29  = EC6
-                __ASM_EMIT("ldp             q30, q31, [%[P2C], #0x0e0]")    // v30  = MM , v31  = ME
-                __ASM_EMIT("ldp             q12, q13, [%[P2C], #0x100]")    // v12  = C7 , v13  = L2
-                __ASM_EMIT("ldr             q14, [%[P2C], #0x120]")         // v14  = LE
+                POW_LOAD_VALUES
                 __ASM_EMIT("subs            %[count], %[count], #8")
                 __ASM_EMIT("b.lo            2f")
                 // x8 blocks
                 __ASM_EMIT("1:")
                 __ASM_EMIT("ldp             q0, q1, [%[src]]")
-                LOGN_CORE_X8("v30", "v31", "v16", "v17", "v18", "v19", "v20", "v21", "v22", "v12")
+                POW_LOG_X8
                 __ASM_EMIT("ldp             q4, q5, [%[x]]")                // q4 = x
                 __ASM_EMIT("fmla            v2.4s, v0.4s, v14.4s")          // v2 = 2*y*L*log2(E) + R
                 __ASM_EMIT("fmla            v3.4s, v1.4s, v14.4s")
                 __ASM_EMIT("fmul            v0.4s, v2.4s, v4.4s")           // q0 = (2*y*L*log2(E) + R)*x = log(v[i])*x[i]
                 __ASM_EMIT("fmul            v1.4s, v3.4s, v5.4s")
-                POW2_CORE_X8("v31", "v13", "v23", "v24", "v25", "v26", "v27", "v28", "v29", "v12")
+                POW_POW2_X8
                 __ASM_EMIT("subs            %[count], %[count], #8")
                 __ASM_EMIT("stp             q0, q1, [%[dst]]")
                 __ASM_EMIT("add             %[src], %[src], #0x20")
@@ -441,11 +417,11 @@ namespace lsp
                 __ASM_EMIT("adds            %[count], %[count], #4")
                 __ASM_EMIT("b.lt            4f")
                 __ASM_EMIT("ldr             q0, [%[src]]")
-                LOGN_CORE_X8("v30", "v31", "v16", "v17", "v18", "v19", "v20", "v21", "v22", "v12")
+                POW_LOG_X4
                 __ASM_EMIT("ldr             q4, [%[x]]")                    // q4 = x
                 __ASM_EMIT("fmla            v2.4s, v0.4s, v14.4s")          // v2 = 2*y*L*log2(E) + R
                 __ASM_EMIT("fmul            v0.4s, v2.4s, v4.4s")           // q0 = (2*y*L*log2(E) + R)*x = log(v[i])*x[i]
-                POW2_CORE_X8("v31", "v13", "v23", "v24", "v25", "v26", "v27", "v28", "v29", "v12")
+                POW_POW2_X4
                 __ASM_EMIT("subs            %[count], %[count], #4")
                 __ASM_EMIT("str             q0, [%[dst]]")
                 __ASM_EMIT("add             %[src], %[src], #0x10")
@@ -467,10 +443,10 @@ namespace lsp
                 __ASM_EMIT("ld1             {v0.d}[1], [%[src]]")
                 __ASM_EMIT("ld1             {v15.d}[1], [%[x]]")
                 __ASM_EMIT("8:")
-                LOGN_CORE_X4("v30", "v31", "v16", "v17", "v18", "v19", "v20", "v21", "v22", "v12")
+                POW_LOG_X4
                 __ASM_EMIT("fmla            v2.4s, v0.4s, v14.4s")          // v2 = 2*y*L*log2(E) + R
                 __ASM_EMIT("fmul            v0.4s, v2.4s, v15.4s")          // q0 = (2*y*L*log2(E) + R)*v = log(c[i])*v
-                POW2_CORE_X4("v31", "v13", "v23", "v24", "v25", "v26", "v27", "v28", "v29", "v12")
+                POW_POW2_X4
                 __ASM_EMIT("tst             %[count], #1")
                 __ASM_EMIT("b.eq            10f")
                 __ASM_EMIT("st1             {v0.s}[0], [%[dst]]")
@@ -502,28 +478,19 @@ namespace lsp
     //        for (size_t i=0; i<count; ++i)
     //            dst[i] = expf(x[i] * logf(v[i]));
             ARCH_AARCH64_ASM(
-                __ASM_EMIT("ldp             q16, q17, [%[P2C], #0x000]")    // v16  = LC0, v17  = LC1
-                __ASM_EMIT("ldp             q18, q19, [%[P2C], #0x020]")    // v18  = LC2, v19  = LC3
-                __ASM_EMIT("ldp             q20, q21, [%[P2C], #0x040]")    // v20  = LC4, v21  = LC5
-                __ASM_EMIT("ldp             q22, q23, [%[P2C], #0x060]")    // v22  = LC6, v23  = EC5
-                __ASM_EMIT("ldp             q24, q25, [%[P2C], #0x080]")    // v24  = EC4, v25  = EC3
-                __ASM_EMIT("ldp             q26, q27, [%[P2C], #0x0a0]")    // v26  = EC2, v27  = EC1
-                __ASM_EMIT("ldp             q28, q29, [%[P2C], #0x0c0]")    // v28  = EC0, v29  = EC6
-                __ASM_EMIT("ldp             q30, q31, [%[P2C], #0x0e0]")    // v30  = MM , v31  = ME
-                __ASM_EMIT("ldp             q12, q13, [%[P2C], #0x100]")    // v12  = C7 , v13  = L2
-                __ASM_EMIT("ldr             q14, [%[P2C], #0x120]")         // v14  = LE
+                POW_LOAD_VALUES
                 __ASM_EMIT("subs            %[count], %[count], #8")
                 __ASM_EMIT("b.lo            2f")
                 // x8 blocks
                 __ASM_EMIT("1:")
                 __ASM_EMIT("ldp             q0, q1, [%[dst]]")
-                LOGN_CORE_X8("v30", "v31", "v16", "v17", "v18", "v19", "v20", "v21", "v22", "v12")
+                POW_LOG_X8
                 __ASM_EMIT("ldp             q4, q5, [%[x]]")                // q4 = x
                 __ASM_EMIT("fmla            v2.4s, v0.4s, v14.4s")          // v2 = 2*y*L*log2(E) + R
                 __ASM_EMIT("fmla            v3.4s, v1.4s, v14.4s")
                 __ASM_EMIT("fmul            v0.4s, v2.4s, v4.4s")           // q0 = (2*y*L*log2(E) + R)*x = log(v[i])*x[i]
                 __ASM_EMIT("fmul            v1.4s, v3.4s, v5.4s")
-                POW2_CORE_X8("v31", "v13", "v23", "v24", "v25", "v26", "v27", "v28", "v29", "v12")
+                POW_POW2_X8
                 __ASM_EMIT("subs            %[count], %[count], #8")
                 __ASM_EMIT("stp             q0, q1, [%[dst]]")
                 __ASM_EMIT("add             %[dst], %[dst], #0x20")
@@ -534,11 +501,11 @@ namespace lsp
                 __ASM_EMIT("adds            %[count], %[count], #4")
                 __ASM_EMIT("b.lt            4f")
                 __ASM_EMIT("ldr             q0, [%[dst]]")
-                LOGN_CORE_X8("v30", "v31", "v16", "v17", "v18", "v19", "v20", "v21", "v22", "v12")
+                POW_LOG_X4
                 __ASM_EMIT("ldr             q4, [%[x]]")                    // q4 = x
                 __ASM_EMIT("fmla            v2.4s, v0.4s, v14.4s")          // v2 = 2*y*L*log2(E) + R
                 __ASM_EMIT("fmul            v0.4s, v2.4s, v4.4s")           // q0 = (2*y*L*log2(E) + R)*x = log(v[i])*x[i]
-                POW2_CORE_X8("v31", "v13", "v23", "v24", "v25", "v26", "v27", "v28", "v29", "v12")
+                POW_POW2_X4
                 __ASM_EMIT("subs            %[count], %[count], #4")
                 __ASM_EMIT("str             q0, [%[dst]]")
                 __ASM_EMIT("add             %[dst], %[dst], #0x10")
@@ -559,10 +526,10 @@ namespace lsp
                 __ASM_EMIT("ld1             {v0.d}[1], [%[dst]]")
                 __ASM_EMIT("ld1             {v15.d}[1], [%[x]]")
                 __ASM_EMIT("8:")
-                LOGN_CORE_X4("v30", "v31", "v16", "v17", "v18", "v19", "v20", "v21", "v22", "v12")
+                POW_LOG_X4
                 __ASM_EMIT("fmla            v2.4s, v0.4s, v14.4s")          // v2 = 2*y*L*log2(E) + R
                 __ASM_EMIT("fmul            v0.4s, v2.4s, v15.4s")          // q0 = (2*y*L*log2(E) + R)*v = log(c[i])*v
-                POW2_CORE_X4("v31", "v13", "v23", "v24", "v25", "v26", "v27", "v28", "v29", "v12")
+                POW_POW2_X4
                 __ASM_EMIT("tst             %[count], #1")
                 __ASM_EMIT("b.eq            10f")
                 __ASM_EMIT("sub             %[dst], %[dst], #0x04")
@@ -589,7 +556,13 @@ namespace lsp
                   "v28", "v29", "v30", "v31"
             );
         }
-    }
-}
+
+    #undef POW_LOG_X4
+    #undef POW_LOG_X8
+    #undef POW_POW2_X8
+    #undef POW_POW2_X4
+    #undef POW_LOAD_VALUES
+    } /* namespace asimd */
+} /* namespace lsp */
 
 #endif /* PRIVATE_DSP_ARCH_AARCH64_ASIMD_PMATH_POW_H_ */
