@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2023 Linux Studio Plugins Project <https://lsp-plug.in/>
- *           (C) 2023 Vladimir Sadovnikov <sadko4u@gmail.com>
+ * Copyright (C) 2025 Linux Studio Plugins Project <https://lsp-plug.in/>
+ *           (C) 2025 Vladimir Sadovnikov <sadko4u@gmail.com>
  *
  * This file is part of lsp-dsp-lib
  * Created on: 31 мар. 2020 г.
@@ -45,19 +45,19 @@ namespace lsp
 
             static const float LOGB_C[] __lsp_aligned16 =
             {
-                LSP_DSP_VEC4(2.0f * M_LOG2E),
-                LSP_DSP_VEC4(2.0f * M_LOG2E)
+                LSP_DSP_VEC4(2.0f * float(M_LOG2E)),
+                LSP_DSP_VEC4(2.0f * float(M_LOG2E))
             };
 
             static const float LOGE_C[] __lsp_aligned16 =
             {
-                LSP_DSP_VEC4(1.0f / M_LOG2E),
-                LSP_DSP_VEC4(1.0f / M_LOG2E)
+                LSP_DSP_VEC4(1.0f / float(M_LOG2E)),
+                LSP_DSP_VEC4(1.0f / float(M_LOG2E))
             };
 
             static const float LOGD_C[] __lsp_aligned16 =
             {
-                LSP_DSP_VEC4(2.0f * M_LOG10E),
+                LSP_DSP_VEC4(2.0f * float(M_LOG10E)),
                 LSP_DSP_VEC4(0.301029995663981f) // 1/log2(10)
             };
         )
