@@ -27,9 +27,11 @@
 #endif /* PRIVATE_DSP_ARCH_GENERIC_IMPL */
 
 #include <private/dsp/arch/generic/pmath/abs_vv.h>
+#include <private/dsp/arch/generic/pmath/cos.h>
 #include <private/dsp/arch/generic/pmath/exp.h>
 #include <private/dsp/arch/generic/pmath/fmop_kx.h>
 #include <private/dsp/arch/generic/pmath/fmop_vv.h>
+#include <private/dsp/arch/generic/pmath/lanczos.h>
 #include <private/dsp/arch/generic/pmath/log.h>
 #include <private/dsp/arch/generic/pmath/lramp.h>
 #include <private/dsp/arch/generic/pmath/minmax.h>
@@ -37,6 +39,7 @@
 #include <private/dsp/arch/generic/pmath/op_kx.h>
 #include <private/dsp/arch/generic/pmath/op_vv.h>
 #include <private/dsp/arch/generic/pmath/pow.h>
+#include <private/dsp/arch/generic/pmath/sin.h>
 #include <private/dsp/arch/generic/pmath/sqr.h>
 #include <private/dsp/arch/generic/pmath/ssqrt.h>
 
