@@ -227,7 +227,7 @@ namespace lsp
                 : [dst] __ASM_ARG_RW(dst),
                   [k] "+r" (src), [count] "+r" (count),
                   [c] "=&r" (c), [d] "=&r" (d), [clen] "=&r" (clen)
-                : [conv] "g" (conv), [length] "g" (length)
+                : [conv] X86_GREG (conv), [length] X86_GREG (length)
                 : "cc", "memory",
                   "%xmm0", "%xmm1", "%xmm2", "%xmm3",
                   "%xmm4", "%xmm5", "%xmm6", "%xmm7"
@@ -422,13 +422,13 @@ namespace lsp
                 : [dst] __ASM_ARG_RW(dst),
                   [k] "+r" (src), [count] "+r" (count),
                   [c] "=&r" (c), [d] "=&r" (d), [clen] "=&r" (clen)
-                : [conv] "g" (conv), [length] "g" (length)
+                : [conv] X86_GREG (conv), [length] X86_GREG (length)
                 : "cc", "memory",
                   "%xmm0", "%xmm1", "%xmm2", "%xmm3",
                   "%xmm4", "%xmm5", "%xmm6", "%xmm7"
             );
         }
-    }
-}
+    } /* namespace avx */
+} /* namespace lsp */
 
 #endif /* PRIVATE_DSP_ARCH_X86_AVX_CONVOLUTION_H_ */
