@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2020 Linux Studio Plugins Project <https://lsp-plug.in/>
- *           (C) 2020 Vladimir Sadovnikov <sadko4u@gmail.com>
+ * Copyright (C) 2024 Linux Studio Plugins Project <https://lsp-plug.in/>
+ *           (C) 2024 Vladimir Sadovnikov <sadko4u@gmail.com>
  *
  * This file is part of lsp-dsp-lib
  * Created on: 31 мар. 2020 г.
@@ -213,6 +213,38 @@ namespace lsp
             );
         }
 
+        void x64_abs_max2(float *dst, const float *src, size_t count)
+        {
+            IF_ARCH_X86_64(size_t off);
+            ARCH_X86_64_ASM
+            (
+                ABS_V4_CORE("dst", "dst", "src", "vmax", OP_DSEL)
+                : [off] "=&r" (off), [count] "+r" (count)
+                : [dst] "r"(dst), [src] "r"(src),
+                  [SIGN] "m" (abs_vv_const)
+                : "cc", "memory",
+                  "%xmm0", "%xmm1", "%xmm2", "%xmm3",
+                  "%xmm4", "%xmm5", "%xmm6", "%xmm7",
+                  "%xmm8", "%xmm9"
+            );
+        }
+
+        void x64_abs_min2(float *dst, const float *src, size_t count)
+        {
+            IF_ARCH_X86_64(size_t off);
+            ARCH_X86_64_ASM
+            (
+                ABS_V4_CORE("dst", "dst", "src", "vmin", OP_DSEL)
+                : [off] "=&r" (off), [count] "+r" (count)
+                : [dst] "r"(dst), [src] "r"(src),
+                  [SIGN] "m" (abs_vv_const)
+                : "cc", "memory",
+                  "%xmm0", "%xmm1", "%xmm2", "%xmm3",
+                  "%xmm4", "%xmm5", "%xmm6", "%xmm7",
+                  "%xmm8", "%xmm9"
+            );
+        }
+
         void x64_abs_add3(float *dst, const float *src1, const float *src2, size_t count)
         {
             IF_ARCH_X86_64(size_t off);
@@ -309,6 +341,38 @@ namespace lsp
             );
         }
 
+        void x64_abs_max3(float *dst, const float *src1, const float *src2, size_t count)
+        {
+            IF_ARCH_X86_64(size_t off);
+            ARCH_X86_64_ASM
+            (
+                ABS_V4_CORE("dst", "src1", "src2", "vmax", OP_DSEL)
+                : [off] "=&r" (off), [count] "+r" (count)
+                : [dst] "r"(dst), [src1] "r" (src1), [src2] "r" (src2),
+                  [SIGN] "m" (abs_vv_const)
+                : "cc", "memory",
+                  "%xmm0", "%xmm1", "%xmm2", "%xmm3",
+                  "%xmm4", "%xmm5", "%xmm6", "%xmm7",
+                  "%xmm8", "%xmm9"
+            );
+        }
+
+        void x64_abs_min3(float *dst, const float *src1, const float *src2, size_t count)
+        {
+            IF_ARCH_X86_64(size_t off);
+            ARCH_X86_64_ASM
+            (
+                ABS_V4_CORE("dst", "src1", "src2", "vmin", OP_DSEL)
+                : [off] "=&r" (off), [count] "+r" (count)
+                : [dst] "r"(dst), [src1] "r" (src1), [src2] "r" (src2),
+                  [SIGN] "m" (abs_vv_const)
+                : "cc", "memory",
+                  "%xmm0", "%xmm1", "%xmm2", "%xmm3",
+                  "%xmm4", "%xmm5", "%xmm6", "%xmm7",
+                  "%xmm8", "%xmm9"
+            );
+        }
+
         #undef ABS_V4_CORE
 
     #define ABS_CORE(DST, SRC)  \
@@ -425,7 +489,7 @@ namespace lsp
 
     #undef OP_DSEL
     #undef OP_RSEL
-    }
-}
+    } /* namespace avx */
+} /* namespace lsp */
 
 #endif /* PRIVATE_DSP_ARCH_X86_AVX_PMATH_ABS_VV_H_ */
