@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2024 Linux Studio Plugins Project <https://lsp-plug.in/>
- *           (C) 2024 Vladimir Sadovnikov <sadko4u@gmail.com>
+ * Copyright (C) 2025 Linux Studio Plugins Project <https://lsp-plug.in/>
+ *           (C) 2025 Vladimir Sadovnikov <sadko4u@gmail.com>
  *
  * This file is part of lsp-dsp-lib
  * Created on: 31 мар. 2020 г.
@@ -70,21 +70,11 @@
         #include <private/dsp/arch/aarch64/asimd/hmath/hdotp.h>
         #include <private/dsp/arch/aarch64/asimd/interpolation/linear.h>
         #include <private/dsp/arch/aarch64/asimd/mix.h>
+        #include <private/dsp/arch/aarch64/asimd/pan.h>
         #include <private/dsp/arch/aarch64/asimd/msmatrix.h>
         #include <private/dsp/arch/aarch64/asimd/pcomplex.h>
         #include <private/dsp/arch/aarch64/asimd/pfft.h>
-        #include <private/dsp/arch/aarch64/asimd/pmath/abs_vv.h>
-        #include <private/dsp/arch/aarch64/asimd/pmath/exp.h>
-        #include <private/dsp/arch/aarch64/asimd/pmath/fmop_kx.h>
-        #include <private/dsp/arch/aarch64/asimd/pmath/fmop_vv.h>
-        #include <private/dsp/arch/aarch64/asimd/pmath/log.h>
-        #include <private/dsp/arch/aarch64/asimd/pmath/lramp.h>
-        #include <private/dsp/arch/aarch64/asimd/pmath/minmax.h>
-        #include <private/dsp/arch/aarch64/asimd/pmath/op_kx.h>
-        #include <private/dsp/arch/aarch64/asimd/pmath/op_vv.h>
-        #include <private/dsp/arch/aarch64/asimd/pmath/pow.h>
-        #include <private/dsp/arch/aarch64/asimd/pmath/sqr.h>
-        #include <private/dsp/arch/aarch64/asimd/pmath/ssqrt.h>
+        #include <private/dsp/arch/aarch64/asimd/pmath.h>
         #include <private/dsp/arch/aarch64/asimd/resampling.h>
         #include <private/dsp/arch/aarch64/asimd/search/minmax.h>
         #include <private/dsp/arch/aarch64/asimd/search/iminmax.h>
@@ -264,6 +254,8 @@
                 EXPORT1(abs_mul2);
                 EXPORT1(abs_div2);
                 EXPORT1(abs_rdiv2);
+                EXPORT1(abs_max2);
+                EXPORT1(abs_min2);
 
                 EXPORT1(abs_add3);
                 EXPORT1(abs_sub3);
@@ -271,6 +263,8 @@
                 EXPORT1(abs_mul3);
                 EXPORT1(abs_div3);
                 EXPORT1(abs_rdiv3);
+                EXPORT1(abs_max3);
+                EXPORT1(abs_min3);
 
                 EXPORT1(h_sum);
                 EXPORT1(h_sqr_sum);
@@ -297,6 +291,16 @@
                 EXPORT1(powvx1);
                 EXPORT1(powvx2);
 
+                EXPORT1(cosf1);
+                EXPORT1(cosf2);
+                EXPORT1(cosf_kp1);
+
+                EXPORT1(sinf1);
+                EXPORT1(sinf2);
+                EXPORT1(sinf_kp1);
+
+                EXPORT1(lanczos1);
+
                 EXPORT1(sqr1);
                 EXPORT1(sqr2);
                 EXPORT1(ssqrt1);
@@ -312,6 +316,9 @@
                 EXPORT1(mix_add3);
                 EXPORT1(mix_add4);
 
+                EXPORT1(depan_lin);
+                EXPORT1(depan_eqpow);
+
                 EXPORT1(lr_to_ms);
                 EXPORT1(lr_to_mid);
                 EXPORT1(lr_to_side);
@@ -325,6 +332,9 @@
                 EXPORT1(abs_min)
                 EXPORT1(abs_max)
                 EXPORT1(abs_minmax)
+                EXPORT1(sign_min)
+                EXPORT1(sign_max)
+                EXPORT1(sign_minmax)
 
                 EXPORT1(min_index)
                 EXPORT1(max_index)
@@ -352,6 +362,7 @@
                 EXPORT1(pcomplex_rcp2);
                 EXPORT1(pcomplex_r2c);
                 EXPORT1(pcomplex_c2r);
+                EXPORT1(pcomplex_corr);
 
                 EXPORT1(pcomplex_r2c_add2);
                 EXPORT1(pcomplex_r2c_sub2);
