@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2020 Linux Studio Plugins Project <https://lsp-plug.in/>
- *           (C) 2020 Vladimir Sadovnikov <sadko4u@gmail.com>
+ * Copyright (C) 2025 Linux Studio Plugins Project <https://lsp-plug.in/>
+ *           (C) 2025 Vladimir Sadovnikov <sadko4u@gmail.com>
  *
  * This file is part of lsp-dsp-lib
  * Created on: 17 нояб. 2020 г.
@@ -39,11 +39,23 @@ namespace lsp
             size_t colocation_x2_v1pv(const dsp::vector3d_t *pl, const dsp::point3d_t *pv);
         }
 
+        namespace sse2
+        {
+            size_t colocation_x2_v1p2(const dsp::vector3d_t *pl, const dsp::point3d_t *p0, const dsp::point3d_t *p1);
+            size_t colocation_x2_v1pv(const dsp::vector3d_t *pl, const dsp::point3d_t *pv);
+        }
+
         namespace sse3
         {
             size_t colocation_x2_v1p2(const dsp::vector3d_t *pl, const dsp::point3d_t *p0, const dsp::point3d_t *p1);
             size_t colocation_x2_v1pv(const dsp::vector3d_t *pl, const dsp::point3d_t *pv);
         }
+
+        namespace avx
+        {
+            size_t colocation_x2_v1p2(const dsp::vector3d_t *pl, const dsp::point3d_t *p0, const dsp::point3d_t *p1);
+            size_t colocation_x2_v1pv(const dsp::vector3d_t *pl, const dsp::point3d_t *pv);
+        }
     )
 
     typedef size_t (* colocation_x2_v1p2_t)(const dsp::vector3d_t *pl, const dsp::point3d_t *p0, const dsp::point3d_t *p1);
@@ -183,9 +195,13 @@ UTEST_BEGIN("dsp.3d", colocation_x2)
             test(#func, func)
 
         IF_ARCH_X86(CALL(sse::colocation_x2_v1p2));
+        IF_ARCH_X86(CALL(sse2::colocation_x2_v1p2));
         IF_ARCH_X86(CALL(sse3::colocation_x2_v1p2));
+        IF_ARCH_X86(CALL(avx::colocation_x2_v1p2));
 
         IF_ARCH_X86(CALL(sse::colocation_x2_v1pv));
+        IF_ARCH_X86(CALL(sse2::colocation_x2_v1pv));
         IF_ARCH_X86(CALL(sse3::colocation_x2_v1pv));
+        IF_ARCH_X86(CALL(avx::colocation_x2_v1pv));
     }
 UTEST_END;
