@@ -47,6 +47,14 @@ namespace lsp
         }
     )
 
+    IF_ARCH_AARCH64(
+        namespace asimd
+        {
+            void fill_rgba(float *dst, float r, float g, float b, float a, size_t count);
+            void fill_hsla(float *dst, float h, float s, float l, float a, size_t count);
+        }
+    )
+
     typedef void (* hsla_to_fill_t)(float *dst, float c1, float c2, float c3, float c4, size_t count);
 }
 
@@ -102,6 +110,9 @@ UTEST_BEGIN("dsp.graphics", fill)
 
         IF_ARCH_ARM(call("neon_d32::fill_rgba", 16, generic::fill_rgba, neon_d32::fill_rgba));
         IF_ARCH_ARM(call("neon_d32::fill_hsla", 16, generic::fill_hsla, neon_d32::fill_hsla));
+
+        IF_ARCH_AARCH64(call("asimd::fill_rgba", 16, generic::fill_rgba, asimd::fill_rgba));
+        IF_ARCH_AARCH64(call("asimd::fill_hsla", 16, generic::fill_hsla, asimd::fill_hsla));
     }
 
 UTEST_END;
