@@ -57,6 +57,13 @@ namespace lsp
         }
     )
 
+    IF_ARCH_AARCH64(
+        namespace asimd
+        {
+            void rgba32_to_bgra32(void *dst, const void *src, size_t count);
+        }
+    )
+
     typedef void (* rgba32_to_bgra32_t)(void *dst, const void *src, size_t count);
 }
 
@@ -113,6 +120,7 @@ UTEST_BEGIN("dsp.graphics", rgba)
         IF_ARCH_X86_64(CALL(sse3::x64_rgba32_to_bgra32, 16));
 
         IF_ARCH_ARM(CALL(neon_d32::rgba32_to_bgra32, 16));
+        IF_ARCH_AARCH64(CALL(asimd::rgba32_to_bgra32, 16));
     }
 
 UTEST_END;
