@@ -45,6 +45,13 @@ namespace lsp
         }
     )
 
+    IF_ARCH_AARCH64(
+        namespace asimd
+        {
+            void rgba_to_bgra32(void *dst, const float *src, size_t count);
+        }
+    )
+
     typedef void (* rgba_to_bgra32_t)(void *dst, const float *src, size_t count);
 }
 
@@ -105,6 +112,7 @@ UTEST_BEGIN("dsp.graphics", rgba_to_bgra32)
     {
         IF_ARCH_X86(call("sse2::rgba_to_bgra32", 16, sse2::rgba_to_bgra32));
         IF_ARCH_ARM(call("neon_d32::rgba_to_bgra32", 16, neon_d32::rgba_to_bgra32));
+        IF_ARCH_AARCH64(call("asimd::rgba_to_bgra32", 16, asimd::rgba_to_bgra32));
     }
 
 UTEST_END;
