@@ -51,6 +51,12 @@ namespace lsp
             void pcomplex_mul2_fma3(float *dst, const float *src, size_t count);
             void pcomplex_mul3_fma3(float *dst, const float *src1, const float *src2, size_t count);
         }
+
+        namespace avx512
+        {
+            void pcomplex_mul2(float *dst, const float *src, size_t count);
+            void pcomplex_mul3(float *dst, const float *src1, const float *src2, size_t count);
+        }
     )
 
     IF_ARCH_X86_64(
@@ -174,6 +180,8 @@ UTEST_BEGIN("dsp.pcomplex", mul)
         IF_ARCH_X86(CALL(avx::pcomplex_mul3, 32));
         IF_ARCH_X86(CALL(avx::pcomplex_mul2_fma3, 32));
         IF_ARCH_X86(CALL(avx::pcomplex_mul3_fma3, 32));
+        IF_ARCH_X86(CALL(avx512::pcomplex_mul2, 64));
+        IF_ARCH_X86(CALL(avx512::pcomplex_mul3, 64));
 
         IF_ARCH_ARM(CALL(neon_d32::pcomplex_mul2, 16));
         IF_ARCH_ARM(CALL(neon_d32::pcomplex_mul3, 16));
