@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2023 Linux Studio Plugins Project <https://lsp-plug.in/>
- *           (C) 2023 Vladimir Sadovnikov <sadko4u@gmail.com>
+ * Copyright (C) 2025 Linux Studio Plugins Project <https://lsp-plug.in/>
+ *           (C) 2025 Vladimir Sadovnikov <sadko4u@gmail.com>
  *
  * This file is part of lsp-dsp-units
  * Created on: 10 июн. 2023 г.
@@ -21,6 +21,7 @@
 
 #include <lsp-plug.in/stdlib/math.h>
 #include <lsp-plug.in/dsp-units/misc/lfo.h>
+#include <lsp-plug.in/dsp-units/misc/quickmath.h>
 
 namespace lsp
 {
@@ -28,36 +29,9 @@ namespace lsp
     {
         namespace lfo
         {
-            static constexpr float      REV_LN100               = 0.5f / M_LN10;
-            static constexpr float      LOG2TOLN                = 1.0f / M_LOG2E;
-
-            static inline float taylor_sinf(float x)
-            {
-                // Taylor series sine approximation for better performance
-                // The argument should be within range -M_PI/2 ... M_PI/2
-                const float x2 = x*x;
-                return x * (1.0f + x2*(-0.166666666667f + x2*(0.00833333333333f + x2 * -0.000198412698413f)));
-            }
-
-            static inline float taylor_logf(float x)
-            {
-                // Using taylor series of arctanh function that can express the logarithm value as:
-                // ln(x) = 2 * arctanh((x-1)/(x+1))
-                union { float f; uint32_t i; } u;
-
-                // Get mantissa and reset it for the input argument
-                u.f = x;
-                const int f = (u.i >> 23) - 127; // f = mant(x)
-                u.i = (u.i & 0x007fffff) | 0x3f800000;
-
-                // Prepare for calculations
-                const float X = u.f;
-                const float y = (X - 1.0f)/(X + 1.0f);
-                const float y2 = y*y;
-
-                return 2.0f*y * (1.0f + y2*(0.333333333333f + y2*(0.2f + y2*(0.142857142857f)))) + f * LOG2TOLN;
-            }
-
+            static constexpr float      LFO_REV_LN100           = 0.5f / M_LN10;
+            static constexpr float      LFO_M_2PI               = 2.0f * M_PI;
+            static constexpr float      LFO_M_4PI               = 4.0f * M_PI;
 
             LSP_DSP_UNITS_PUBLIC
             float triangular(float phase)
@@ -69,8 +43,8 @@ namespace lsp
             float sine(float phase)
             {
                 return (phase >=0.5f) ?
-                    0.5f + 0.5f*taylor_sinf((0.75f - phase) * M_PI * 2.0f) :
-                    0.5f + 0.5f*taylor_sinf((phase - 0.25f) * M_PI * 2.0f);
+                    0.5f + 0.5f * quick_sinf((0.75f - phase) * LFO_M_2PI) :
+                    0.5f + 0.5f * quick_sinf((phase - 0.25f) * LFO_M_2PI);
             }
 
             LSP_DSP_UNITS_PUBLIC
@@ -79,13 +53,13 @@ namespace lsp
                 if (phase >= 0.5f)
                 {
                     return (phase >= 0.75f) ?
-                        0.25f + 0.25f * taylor_sinf((0.875f - phase) * M_PI * 4.0f) :
-                        0.75f + 0.25f * taylor_sinf((0.625f - phase) * M_PI * 4.0f);
+                        0.25f + 0.25f * quick_sinf((0.875f - phase) * LFO_M_4PI) :
+                        0.75f + 0.25f * quick_sinf((0.625f - phase) * LFO_M_4PI);
                 }
 
                 return (phase >= 0.25f) ?
-                    0.75f + 0.25f * sinf((phase - 0.375f) * M_PI * 4.0f) :
-                    0.25f + 0.25f * sinf((phase - 0.125f) * M_PI * 4.0f);
+                    0.75f + 0.25f * sinf((phase - 0.375f) * LFO_M_4PI) :
+                    0.25f + 0.25f * sinf((phase - 0.125f) * LFO_M_4PI);
             }
 
             LSP_DSP_UNITS_PUBLIC
@@ -128,7 +102,7 @@ namespace lsp
             {
                 if (phase >= 0.5f)
                     phase      = 1.0f - phase;
-                return taylor_logf(1.0f + 198.0f *phase) * REV_LN100;
+                return quick_logf(1.0f + 198.0f *phase) * LFO_REV_LN100;
             }
 
             LSP_DSP_UNITS_PUBLIC
@@ -136,7 +110,7 @@ namespace lsp
             {
                 if (phase >= 0.5f)
                     phase      = 1.0f - phase;
-                return 1.0f - logf(100.0f - 198.0f * phase) * REV_LN100;
+                return 1.0f - quick_logf(100.0f - 198.0f * phase) * LFO_REV_LN100;
             }
 
             LSP_DSP_UNITS_PUBLIC
