@@ -505,6 +505,16 @@ namespace lsp
          */
         status_t        parse_note_frequency(float *dst, const char *text, const port_t *meta);
 
+        /**
+         * Try to convert the string to the note name and compute it's main tone frequency considering
+         * the A2 being 440 Hz.
+         *
+         * @param dst destination pointer to store note number
+         * @param text text to parse
+         * @return status of operation
+         */
+        status_t        parse_note_number(ssize_t *dst, const char *text);
+
         /**
          * Parse frequency value. Allows to pass note name considering the A2 being 440 Hz.
          *
@@ -619,6 +629,13 @@ namespace lsp
          * @return plugin format name
          */
         const char     *plugin_format_name(plugin_format_t format);
+
+        /**
+         * Get port role name from the enumeration constant
+         * @param role port role
+         * @return port role name from enumeration constant
+         */
+        const char     *port_role_name(role_t role);
     } /* namespace meta */
 } /* namespace lsp */
 
