@@ -34,15 +34,13 @@ namespace lsp
         }
 
         //---------------------------------------------------------------------
-        const ctl_class_t Widget::metadata = { "Widget", NULL };
+        const ctl_class_t Widget::metadata = { "Widget", &DOMController::metadata };
 
         Widget::Widget(ui::IWrapper *wrapper, tk::Widget *widget):
-            ui::IPortListener(),
+            ctl::DOMController(wrapper),
             sProperties(this)
         {
             pClass          = &metadata;
-
-            pWrapper        = wrapper;
             wWidget         = widget;
         }
 
@@ -54,6 +52,7 @@ namespace lsp
         void Widget::destroy()
         {
             do_destroy();
+            ctl::DOMController::destroy();
         }
 
         void Widget::do_destroy()
@@ -66,19 +65,6 @@ namespace lsp
             wWidget     = NULL;
         }
 
-        bool Widget::instance_of(const ctl_class_t *wclass) const
-        {
-            const ctl_class_t *wc = pClass;
-            while (wc != NULL)
-            {
-                if (wc == wclass)
-                    return true;
-                wc = wc->parent;
-            }
-
-            return false;
-        }
-
         tk::Widget *Widget::widget()
         {
             return wWidget;
@@ -292,18 +278,6 @@ namespace lsp
             return true;
         }
 
-        bool Widget::set_expr(ctl::Expression *expr, const char *param, const char *name, const char *value)
-        {
-            if (expr == NULL)
-                return false;
-            if (strcmp(name, param))
-                return false;
-
-            if (!expr->parse(value))
-                lsp_warn("Failed to parse expression for attribute '%s': %s", name, value);
-            return true;
-        }
-
         bool Widget::set_param(tk::Boolean *b, const char *param, const char *name, const char *value)
         {
             if (b == NULL)
@@ -341,96 +315,6 @@ namespace lsp
             return e->parse(value) == STATUS_OK;
         }
 
-        bool Widget::set_value(bool *v, const char *param, const char *name, const char *value)
-        {
-            if (v == NULL)
-                return false;
-            if (strcmp(param, name))
-                return false;
-            PARSE_BOOL(value, *v = __);
-            return true;
-        }
-
-        bool Widget::set_value(ssize_t *v, const char *param, const char *name, const char *value)
-        {
-            if (v == NULL)
-                return false;
-            if (strcmp(param, name))
-                return false;
-            PARSE_INT(value, *v = __);
-            return true;
-        }
-
-        bool Widget::set_value(size_t *v, const char *param, const char *name, const char *value)
-        {
-            if (v == NULL)
-                return false;
-            if (strcmp(param, name))
-                return false;
-            PARSE_UINT(value, *v = __);
-            return true;
-        }
-
-        bool Widget::set_value(float *v, const char *param, const char *name, const char *value)
-        {
-            if (v == NULL)
-                return false;
-            if (strcmp(param, name))
-                return false;
-            PARSE_FLOAT(value, *v = __);
-            return true;
-        }
-
-        bool Widget::set_value(LSPString *v, const char *param, const char *name, const char *value)
-        {
-            if (v == NULL)
-                return false;
-            if (strcmp(param, name))
-                return false;
-
-            v->set_utf8(value);
-            return true;
-        }
-
-        bool Widget::link_port(ui::IPort **port, const char *id)
-        {
-            ui::IPort *oldp = *port;
-            ui::IPort *newp = pWrapper->port(id);
-            if (oldp == newp)
-                return true;
-
-            if (oldp != NULL)
-                oldp->unbind(this);
-            if (newp != NULL)
-                newp->bind(this);
-
-            *port           = newp;
-
-            return true;
-        }
-
-        bool Widget::bind_port(ui::IPort **port, const char *param, const char *name, const char *value)
-        {
-            if (strcmp(param, name))
-                return false;
-            if (port == NULL)
-                return false;
-
-            ui::IPort *oldp = *port;
-            ui::IPort *newp = pWrapper->port(value);
-            if (oldp == newp)
-                return true;
-
-            if (oldp != NULL)
-                oldp->unbind(this);
-            if (newp != NULL)
-                newp->bind(this);
-
-            *port           = newp;
-
-            return true;
-        }
-
         bool Widget::set_embedding(tk::Embedding *e, const char *name, const char *value)
         {
             if (e == NULL)
@@ -479,6 +363,10 @@ namespace lsp
 
         status_t Widget::init()
         {
+            status_t res = ctl::DOMController::init();
+            if (res != STATUS_OK)
+                return res;
+
             pWrapper->add_schema_listener(this);
 
             if (wWidget != NULL)
@@ -502,6 +390,8 @@ namespace lsp
 
         void Widget::set(ui::UIContext *ctx, const char *name, const char *value)
         {
+            ctl::DOMController::set(ctx, name, value);
+
             if (wWidget != NULL)
             {
                 set_param(wWidget->scaling(), "scaling", name, value);
@@ -551,22 +441,6 @@ namespace lsp
             sBgInherit.set("ibg", name, value);
         }
 
-        void Widget::begin(ui::UIContext *ctx)
-        {
-        }
-
-        void Widget::end(ui::UIContext *ctx)
-        {
-        }
-
-        void Widget::notify(ui::IPort *port, size_t flags)
-        {
-        }
-
-        void Widget::reloaded(const tk::StyleSheet *sheet)
-        {
-        }
-
         void Widget::property_changed(tk::Property *prop)
         {
         }
