@@ -63,9 +63,9 @@ namespace lsp
             expr::destroy_value(&value);
         }
 
-        void Float::init(ui::IWrapper *wrapper, tk::Float *prop)
+        void Float::init(ui::IWrapper *wrapper, tk::Float *prop, expr::Resolver *resolver)
         {
-            Property::init(wrapper);
+            Property::init(wrapper, resolver);
             pProp       = prop;
 
             if (pWrapper != NULL)
@@ -84,6 +84,6 @@ namespace lsp
             return true;
         }
 
-    }
-}
+    } /* namespace ctl */
+} /* namespace lsp */
 
