@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2022 Linux Studio Plugins Project <https://lsp-plug.in/>
- *           (C) 2022 Vladimir Sadovnikov <sadko4u@gmail.com>
+ * Copyright (C) 2024 Linux Studio Plugins Project <https://lsp-plug.in/>
+ *           (C) 2024 Vladimir Sadovnikov <sadko4u@gmail.com>
  *
  * This file is part of lsp-plugin-fw
  * Created on: 7 февр. 2022 г.
@@ -37,43 +37,49 @@ namespace lsp
     {
         const enumeration_t plugin_groups[] =
         {
-            { meta::C_DELAY,        "Delay" },
-            { meta::C_REVERB,       "Reverb" },
-            { meta::C_DISTORTION,   "Distortion" },
-            { meta::C_WAVESHAPER,   "Waveshaper" },
-            { meta::C_DYNAMICS,     "Dynamics" },
-            { meta::C_AMPLIFIER,    "Amplifier" },
-            { meta::C_COMPRESSOR,   "Compressor" },
-            { meta::C_ENVELOPE,     "Envelope" },
-            { meta::C_EXPANDER,     "Expander" },
-            { meta::C_GATE,         "Gate" },
-            { meta::C_LIMITER,      "Limiter" },
-            { meta::C_FILTER,       "Filter" },
-            { meta::C_ALLPASS,      "Allpass" },
-            { meta::C_BANDPASS,     "Bandpass" },
-            { meta::C_COMB,         "Comb" },
-            { meta::C_EQ,           "Equalizer" },
-            { meta::C_MULTI_EQ,     "Multiband Equalizer" },
-            { meta::C_PARA_EQ,      "Parametric Equalizer" },
-            { meta::C_HIGHPASS,     "Highpass" },
-            { meta::C_LOWPASS,      "Lowpass" },
-            { meta::C_GENERATOR,    "Generator" },
-            { meta::C_CONSTANT,     "Constant" },
-            { meta::C_INSTRUMENT,   "Instrument" },
-            { meta::C_OSCILLATOR,   "Oscillator" },
-            { meta::C_MODULATOR,    "Modulator" },
-            { meta::C_CHORUS,       "Chorus" },
-            { meta::C_FLANGER,      "Flanger" },
-            { meta::C_PHASER,       "Phaser" },
-            { meta::C_SIMULATOR,    "Simulator" },
-            { meta::C_SPATIAL,      "Spatial" },
-            { meta::C_SPECTRAL,     "Spectral" },
-            { meta::C_PITCH,        "Pitch" },
-            { meta::C_UTILITY,      "Utility" },
-            { meta::C_ANALYSER,     "Analyser" },
-            { meta::C_CONVERTER,    "Converter" },
-            { meta::C_FUNCTION,     "Function" },
-            { meta::C_MIXER,        "Mixer" },
+            { meta::C_DELAY,            "Delay" },
+            { meta::C_REVERB,           "Reverb" },
+            { meta::C_DISTORTION,       "Distortion" },
+            { meta::C_WAVESHAPER,       "Waveshaper" },
+            { meta::C_DYNAMICS,         "Dynamics" },
+            { meta::C_AMPLIFIER,        "Amplifier" },
+            { meta::C_COMPRESSOR,       "Compressor" },
+            { meta::C_ENVELOPE,         "Envelope" },
+            { meta::C_EXPANDER,         "Expander" },
+            { meta::C_GATE,             "Gate" },
+            { meta::C_LIMITER,          "Limiter" },
+            { meta::C_FILTER,           "Filter" },
+            { meta::C_ALLPASS,          "Allpass" },
+            { meta::C_BANDPASS,         "Bandpass" },
+            { meta::C_COMB,             "Comb" },
+            { meta::C_EQ,               "Equalizer" },
+            { meta::C_MULTI_EQ,         "Multiband Equalizer" },
+            { meta::C_PARA_EQ,          "Parametric Equalizer" },
+            { meta::C_HIGHPASS,         "Highpass" },
+            { meta::C_LOWPASS,          "Lowpass" },
+            { meta::C_GENERATOR,        "Generator" },
+            { meta::C_CONSTANT,         "Constant" },
+            { meta::C_INSTRUMENT,       "Instrument" },
+            { meta::C_DRUM,             "Drum Instrument" },
+            { meta::C_EXTERNAL,         "External Instrument" },
+            { meta::C_PIANO,            "Piano Instrument" },
+            { meta::C_SAMPLER,          "Sampler" },
+            { meta::C_SYNTH,            "Synthesizer" },
+            { meta::C_SYNTH_SAMPLER,    "Synthesizer Sampler" },
+            { meta::C_OSCILLATOR,       "Oscillator" },
+            { meta::C_MODULATOR,        "Modulator" },
+            { meta::C_CHORUS,           "Chorus" },
+            { meta::C_FLANGER,          "Flanger" },
+            { meta::C_PHASER,           "Phaser" },
+            { meta::C_SIMULATOR,        "Simulator" },
+            { meta::C_SPATIAL,          "Spatial" },
+            { meta::C_SPECTRAL,         "Spectral" },
+            { meta::C_PITCH,            "Pitch" },
+            { meta::C_UTILITY,          "Utility" },
+            { meta::C_ANALYSER,         "Analyser" },
+            { meta::C_CONVERTER,        "Converter" },
+            { meta::C_FUNCTION,         "Function" },
+            { meta::C_MIXER,            "Mixer" },
             { -1, NULL }
         };
 
