@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2020 Linux Studio Plugins Project <https://lsp-plug.in/>
- *           (C) 2020 Vladimir Sadovnikov <sadko4u@gmail.com>
+ * Copyright (C) 2025 Linux Studio Plugins Project <https://lsp-plug.in/>
+ *           (C) 2025 Vladimir Sadovnikov <sadko4u@gmail.com>
  *
  * This file is part of lsp-runtime-lib
  * Created on: 24 апр. 2020 г.
@@ -24,7 +24,7 @@
 
 #include <lsp-plug.in/runtime/version.h>
 
-#ifndef USE_LIBSNDFILE
+#ifdef PLATFORM_WINDOWS
 
 #include <lsp-plug.in/common/types.h>
 #include <lsp-plug.in/common/status.h>
@@ -110,6 +110,6 @@ namespace lsp
     } /* namespace mm */
 } /* namespace lsp */
 
-#endif /* USE_LIBSNDFILE */
+#endif /* PLATFORM_WINDOWS */
 
 #endif /* PRIVATE_MM_MMIOREADER_H_ */
