@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2024 Linux Studio Plugins Project <https://lsp-plug.in/>
- *           (C) 2024 Vladimir Sadovnikov <sadko4u@gmail.com>
+ * Copyright (C) 2025 Linux Studio Plugins Project <https://lsp-plug.in/>
+ *           (C) 2025 Vladimir Sadovnikov <sadko4u@gmail.com>
  *
  * This file is part of lsp-runtime-lib
  * Created on: 8 февр. 2019 г.
@@ -1601,7 +1601,7 @@ namespace lsp
         {
             fattr_t attr;
             status_t res = File::stat(&sPath, &attr);
-            return (res != STATUS_OK) ? attr.size : -res;
+            return (res == STATUS_OK) ? attr.size : -res;
         }
 
         bool Path::exists() const
