@@ -38,19 +38,19 @@ namespace lsp
         "vn 0 0 1\n"
         "f 1//1 2//1 3//1\n"
         "\n"
-        "o   Triangle 2\n\r"
-        "v -2.0 -1.0 -2.0\n\r"
-        "v 2.0 -1.0 -2.0\n\r"
-        "v 0.0 2.0 -2.0\n\r"
-        "vt -2.0 -1.0\n\r"
-        "vt 2.0 -1.0\n\r"
-        "vt 0.0 2.0\n\r"
-        "vn 0.0 0.0 1.0\n\r"
-        "vn 0.1 0.1 1.0\n\r"
-        "f 4/1/2 5/2/2 6/3/3\n\r"
-        "f -1/-1/-1 -2/-2/-1 -3/-3/-2\n\r"
-        "\n\r"
-        "\n\r";
+        "o   Triangle 2\r\n"
+        "v -2.0 -1.0 -2.0\r\n"
+        "v 2.0 -1.0 -2.0\r\n"
+        "v 0.0 2.0 -2.0\r\n"
+        "vt -2.0 -1.0\r\n"
+        "vt 2.0 -1.0\r\n"
+        "vt 0.0 2.0\r\n"
+        "vn 0.0 0.0 1.0\r\n"
+        "vn 0.1 0.1 1.0\r\n"
+        "f 4/1/2 5/2/2 6/3/3\r\n"
+        "f -1/-1/-1 -2/-2/-1 -3/-3/-2\r\n"
+        "\r\n"
+        "\r\n";
 
     static const char *output =
         "BOLS Triangle 1\n"
