@@ -130,10 +130,6 @@ namespace lsp
                 prop::Boolean                   sInvertMouseVScroll;
 
             protected:
-                float                           limit_value(float value);
-                float                           get_normalized_value();
-                void                            update();
-                void                            update_cursor_state(ssize_t x, ssize_t y, bool set);
                 float                           update_value(float value);
                 void                            sync_button_pos();
                 style::FaderColors             *select_colors();
