@@ -76,7 +76,6 @@ namespace lsp
                 sFont.bind("font", this);
                 sBorderSize.bind("border.size", this);
                 sBorderRadius.bind("border.radius", this);
-                sActive.bind("active", this);
 
                 // Configure
                 c = &vColors[style::TABITEM_NORMAL];
@@ -125,7 +124,6 @@ namespace lsp
                 sFont.set_size(12.0f);
                 sBorderSize.set(1);
                 sBorderRadius.set(4);
-                sActive.set(true);
             LSP_TK_STYLE_IMPL_END
             LSP_TK_BUILTIN_STYLE(TabItem, "TabItem", "Tab");
 
@@ -154,8 +152,7 @@ namespace lsp
             sTextPadding(&sProperties),
             sFont(&sProperties),
             sBorderSize(&sProperties),
-            sBorderRadius(&sProperties),
-            sActive(&sProperties)
+            sBorderRadius(&sProperties)
         {
             pClass      = &metadata;
 
@@ -223,7 +220,6 @@ namespace lsp
             sFont.bind("font", &sStyle);
             sBorderSize.bind("border.size", &sStyle);
             sBorderRadius.bind("border.radius", &sStyle);
-            sActive.bind("active", &sStyle);
 
             return STATUS_OK;
         }
@@ -251,9 +247,6 @@ namespace lsp
                     break;
                 }
 
-            if (sActive.is(prop))
-                query_draw();
-
             if (prop->one_of(sText, sTextAdjust, sTextLayout, sTextPadding, sFont, sBorderSize, sBorderRadius))
                 query_resize();
         }
