@@ -57,7 +57,6 @@ namespace lsp
                 sTextPadding.bind("text.padding", this);
                 sConstraints.bind("size.constraints", this);
                 sGradient.bind("gradient", this);
-                sActive.bind("active", this);
                 sBorderSize.bind("border.size", this);
                 sBorderPressedSize.bind("border.pressed.size", this);
 
@@ -88,7 +87,6 @@ namespace lsp
                 sTextPadding.set(2, 2, 2, 2);
                 sConstraints.set_all(-1);
                 sGradient.set(true);
-                sActive.set(true);
                 sBorderSize.set(4);
                 sBorderPressedSize.set(3);
 
@@ -133,7 +131,6 @@ namespace lsp
             sTextPadding(&sProperties),
             sConstraints(&sProperties),
             sGradient(&sProperties),
-            sActive(&sProperties),
             sBorderSize(&sProperties),
             sBorderPressedSize(&sProperties)
         {
@@ -190,7 +187,6 @@ namespace lsp
             sTextPadding.bind("text.padding", &sStyle);
             sConstraints.bind("size.constraints", &sStyle);
             sGradient.bind("gradient", &sStyle);
-            sActive.bind("active", &sStyle);
             sBorderSize.bind("border.size", &sStyle);
             sBorderPressedSize.bind("border.pressed.size", &sStyle);
 
@@ -216,9 +212,6 @@ namespace lsp
             if (colors->property_changed(prop))
                 query_draw();
 
-            if (sActive.is(prop))
-                query_draw();
-
             if (prop->one_of(sValue, sGradient))
                 query_draw();
 
@@ -299,10 +292,10 @@ namespace lsp
             sButton.nTop            = r->nTop  + ((r->nHeight - sButton.nHeight) >> 1);
         }
 
-        void FileButton::draw(ws::ISurface *s)
+        void FileButton::draw(ws::ISurface *s, bool force)
         {
             float v                 = sValue.get_normalized();
-            float bright            = sBrightness.get();
+            float bright            = select_brightness();
             lsp::Color bg;
             const style::FileButtonColors *colors = select_colors();
 
