@@ -30,6 +30,7 @@
 #include <lsp-plug.in/common/types.h>
 #include <lsp-plug.in/lltl/parray.h>
 
+#include <private/gl/Data.h>
 #include <private/gl/IContext.h>
 
 namespace lsp
@@ -38,13 +39,7 @@ namespace lsp
     {
         namespace gl
         {
-            enum texture_format_t
-            {
-                TEXTURE_UNKNOWN     = -1,    // No texture format specified
-                TEXTURE_RGBA32      = 0,     // 8-bit alpha component
-                TEXTURE_ALPHA8      = 1,     // 8-bit alpha component
-                TEXTURE_PRGBA32     = 2,     // 32-bit color with 8 bits per red, gree, blue and alpha components, alpha is premultiplied
-            };
+            class IContext;
 
             class LSP_HIDDEN_MODIFIER Texture
             {
